aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--app/decorators/controllers/refinery/pages_controller_decorator.rb14
1 files changed, 7 insertions, 7 deletions
diff --git a/app/decorators/controllers/refinery/pages_controller_decorator.rb b/app/decorators/controllers/refinery/pages_controller_decorator.rb
index 10accb0..77a9434 100644
--- a/app/decorators/controllers/refinery/pages_controller_decorator.rb
+++ b/app/decorators/controllers/refinery/pages_controller_decorator.rb
@@ -18,8 +18,7 @@ ApplicationController.class_eval do
# on every page.
#
find_all_blog_categories
- #find_tags
- calc_tags
+ find_tags
end
def populate_home_page
@@ -30,11 +29,12 @@ ApplicationController.class_eval do
.page(params[:page])
end
- def calc_tags
- # Limit the number of tags to show:
- # This should show the 50 most popular tags from the past 30 days.
- # I think this is a fair compromise between most popular and recent.
-
+ # Override Refinery::Blog::ControllerHelper.find_tags
+ #
+ # Limit the number of tags to show:
+ # This should show the 50 most popular tags from the past 30 days.
+ # I think this is a fair compromise between most popular and recent.
+ def find_tags
opts = {
:order => 'count DESC',
:start_at => 30.days.ago,